@@ -6,7 +6,7 @@
 #########################################################################
 #
 # SPDX-FileCopyrightText: 2008-2021 The Tryton Community <info@tryton.org>
-# SPDX-FileCopyrightText: 2017-2022 GNU Health Community <info@gnuhealth.org>
+# SPDX-FileCopyrightText: 2017-2023 GNU Health Community <info@gnuhealth.org>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -87,9 +87,10 @@ class IconFactory:
         del cls._gnuhealth_icons[:]
 
         try:
-            icons = rpc.execute('model', 'ir.ui.icon', 'list_icons',
+            icons = rpc.execute(
+                'model', 'ir.ui.icon', 'list_icons',
                 rpc.CONTEXT)
-            
+
         except GNUHealthServerError:
             icons = []
         for icon_id, icon_name in icons:
@@ -112,11 +113,12 @@ class IconFactory:
         except KeyError:
             return
         idx = cls._gnuhealth_icons.index(icon_ref)
-        to_load = slice(max(0, idx - cls.batchnum // 2),
-            idx + cls.batchnum // 2)
+        to_load = slice(max(
+            0, idx - cls.batchnum // 2), idx + cls.batchnum // 2)
         ids = [e[0] for e in cls._gnuhealth_icons[to_load]]
         try:
-            icons = rpc.execute('model', 'ir.ui.icon', 'read', ids,
+            icons = rpc.execute(
+                'model', 'ir.ui.icon', 'read', ids,
                 ['name', 'icon'], rpc.CONTEXT)
         except GNUHealthServerError:
             icons = []
@@ -133,10 +135,11 @@ class IconFactory:
             return
         colors = CONFIG['icon.colors'].split(',')
         cls.register_icon(iconname)
-        if iconname in ("tryton-open", "tryton-launch", "tryton-cancel",
-            "tryton-ok", "tryton-go-next", "tryton-info",
-            "tryton-forward", "tryton-back", "tryton-refresh"):
-            iconname = iconname.replace("tryton","gnuhealth")
+        if iconname in (
+                "tryton-open", "tryton-launch", "tryton-cancel",
+                "tryton-ok", "tryton-go-next", "tryton-info",
+                "tryton-forward", "tryton-back", "tryton-refresh"):
+            iconname = iconname.replace("tryton", "gnuhealth")
         if iconname not in cls._pixbufs[(size, badge)]:
             if iconname in cls._icons:
                 data = cls._icons[iconname]
@@ -234,7 +237,8 @@ class ModelAccess(object):
         del self._models[:]
 
         try:
-            self._models = rpc.execute('model', 'ir.model', 'list_models',
+            self._models = rpc.execute(
+                'model', 'ir.model', 'list_models',
                 rpc.CONTEXT)
         except GNUHealthServerError:
             pass
@@ -245,10 +249,11 @@ class ModelAccess(object):
         if model not in self._models:
             self.load_models(refresh=True)
         idx = self._models.index(model)
-        to_load = slice(max(0, idx - self.batchnum // 2),
-            idx + self.batchnum // 2)
+        to_load = slice(
+            max(0, idx - self.batchnum // 2), idx + self.batchnum // 2)
         try:
-            access = rpc.execute('model', 'ir.model.access', 'get_access',
+            access = rpc.execute(
+                'model', 'ir.model.access', 'get_access',
                 self._models[to_load], rpc.CONTEXT)
         except GNUHealthServerError:
             access = {}
@@ -265,8 +270,8 @@ class ModelHistory(object):
     def load_history(self):
         self._models.clear()
         try:
-            self._models.update(rpc.execute('model', 'ir.model',
-                    'list_history', rpc.CONTEXT))
+            self._models.update(
+                rpc.execute('model', 'ir.model', 'list_history', rpc.CONTEXT))
         except GNUHealthServerError:
             pass
 
@@ -312,8 +317,8 @@ class ViewSearch(object):
 
     def load_searches(self):
         try:
-            self.searches = rpc.execute('model', 'ir.ui.view_search',
-                'get_search', rpc.CONTEXT)
+            self.searches = rpc.execute(
+                'model', 'ir.ui.view_search', 'get_search', rpc.CONTEXT)
         except GNUHealthServerError:
             self.searches = {}
 
@@ -322,7 +327,8 @@ class ViewSearch(object):
 
     def add(self, model, name, domain):
         try:
-            id_, = RPCExecute('model', 'ir.ui.view_search',
+            id_, = RPCExecute(
+                'model', 'ir.ui.view_search',
                 'create', [{
                         'model': model,
                         'name': name,
@@ -407,8 +413,9 @@ def selection(title, values, alwaysask=False):
         i += 1
 
     treeview.set_model(model)
-    treeview.connect('row-activated',
-            lambda x, y, z: dialog.response(Gtk.ResponseType.OK) or True)
+    treeview.connect(
+        'row-activated',
+        lambda x, y, z: dialog.response(Gtk.ResponseType.OK) or True)
 
     dialog.show_all()
     response = dialog.run()
@@ -426,22 +433,26 @@ def selection(title, values, alwaysask=False):
     return res
 
 
-def file_selection(title, filename='',
+def file_selection(
+    title, filename='',
         action=Gtk.FileChooserAction.OPEN, preview=True, multi=False,
         filters=None):
     parent = get_toplevel_window()
     if action == Gtk.FileChooserAction.OPEN:
-        buttons = (set_underline(_("Cancel")), Gtk.ResponseType.CANCEL,
+        buttons = (
+            set_underline(_("Cancel")), Gtk.ResponseType.CANCEL,
             set_underline(_("Select")), Gtk.ResponseType.OK)
     else:
-        buttons = (set_underline(_("Cancel")), Gtk.ResponseType.CANCEL,
+        buttons = (
+            set_underline(_("Cancel")), Gtk.ResponseType.CANCEL,
             set_underline(_("Save")), Gtk.ResponseType.OK)
     win = Gtk.FileChooserDialog(
         title=title, transient_for=parent, action=action)
     win.add_buttons(*buttons)
     win.set_icon(GNUHEALTH_ICON)
     if filename:
-        if action in (Gtk.FileChooserAction.SAVE,
+        if action in (
+            Gtk.FileChooserAction.SAVE,
                 Gtk.FileChooserAction.CREATE_FOLDER):
             win.set_current_name(filename)
         else:
@@ -514,8 +525,8 @@ def file_write(filename, data):
 
 def file_open(filename, type=None, print_p=False):
     def save():
-        save_name = file_selection(_('Save As...'),
-                action=Gtk.FileChooserAction.SAVE)
+        save_name = file_selection(
+            _('Save As...'), action=Gtk.FileChooserAction.SAVE)
         if save_name:
             file_p = open(filename, 'rb')
             save_p = open(save_name, 'wb+')
@@ -646,7 +657,8 @@ class UniqueDialog(object):
 
 class MessageDialog(UniqueDialog):
 
-    def build_dialog(self, parent, message, msg_type=Gtk.MessageType.INFO,
+    def build_dialog(
+        self, parent, message, msg_type=Gtk.MessageType.INFO,
             buttons=Gtk.ButtonsType.OK, secondary=None):
         dialog = Gtk.MessageDialog(
             transient_for=parent, modal=True, destroy_with_parent=True,
@@ -911,8 +923,8 @@ def check_version(box, version=__version__):
 
 
 def to_xml(string):
-    return string.replace('&', '&amp;'
-        ).replace('<', '&lt;').replace('>', '&gt;')
+    return string.replace(
+        '&', '&amp;').replace('<', '&lt;').replace('>', '&gt;')
 
 
 PLOCK = Lock()
@@ -932,8 +944,7 @@ def process_exception(exception, *args, **kwargs):
                             'user': rpc._USER,
                             'name': name,
                             'always': (res == 'always'),
-                            }],
-                    process_exception=False)
+                            }], process_exception=False)
                 return rpc_execute(*args)
         elif exception.faultCode == 'UserError':
             msg, description, domain = exception.args
