@@ -6,7 +6,7 @@
 #########################################################################
 #
 # SPDX-FileCopyrightText: 2008-2021 The Tryton Community <info@tryton.org>
-# SPDX-FileCopyrightText: 2017-2022 GNU Health Community <info@gnuhealth.org>
+# SPDX-FileCopyrightText: 2017-2023 GNU Health Community <info@gnuhealth.org>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -29,14 +29,12 @@ _ = gettext.gettext
 
 
 def get_config_dir():
-    if os.name == 'nt':
-        appdata = os.environ['APPDATA']
-        if not isinstance(appdata, str):
-            appdata = str(appdata, sys.getfilesystemencoding())
-        return os.path.join(appdata, '.config', 'gnuhealth',
-                __version__.rsplit('.', 1)[0])
-    return os.path.join(os.environ['HOME'], '.config', 'gnuhealth',
-            __version__.rsplit('.', 1)[0])
+    # Allow releases in the form of major.minor.patch (X.Y.N)
+    # and Release Candidate versions X.YrcN
+    # Returns: X.Y
+    return os.path.join(
+        os.environ['HOME'], '.config', 'gnuhealth',
+        '.'.join(__version__.split('.', 2)[:2]).split('rc')[0])
 
 
 if not os.path.isdir(get_config_dir()):
@@ -52,8 +50,7 @@ class ConfigManager(object):
     "Config manager"
 
     def __init__(self):
-        short_version = '.'.join(__version__.split('.', 2)[:2])
-        demo_server = 'health.gnusolidario.org'
+        demo_server = 'federation.gnuhealth.org'
         demo_database = ''
         self.defaults = {
             'login.profile': demo_server,
@@ -61,7 +58,7 @@ class ConfigManager(object):
             'login.host': demo_server,
             'login.db': demo_database,
             'login.expanded': True,
-            'client.title': 'GNU Health',
+            'client.title': 'GNU Health HMIS',
             'client.toolbar': 'default',
             'client.maximize': False,
             'client.save_width_height': True,
@@ -78,7 +75,7 @@ class ConfigManager(object):
             'calendar.colors': '#fff,#3465a4',
             'graph.color': '#3465a4',
             'image.max_size': 10 ** 6,
-            'client.cli_position' : 'top',
+            'client.cli_position': 'top',
             'menu.pane': 200,
             'menu.expanded': True,
         }
@@ -88,23 +85,29 @@ class ConfigManager(object):
         self.arguments = []
 
     def parse(self):
-        parser = optparse.OptionParser(version=("GNU Health %s" % __version__),
-                usage="Usage: %prog [options] [url]")
-        parser.add_option("-c", "--config", dest="config",
-                help=_("specify alternate config file"))
-        parser.add_option("-d", "--dev", action="store_true",
-                default=False, dest="dev",
-                help=_("development mode"))
-        parser.add_option("-v", "--verbose", action="store_true",
-                default=False, dest="verbose",
-                help=_("logging everything at INFO level"))
-        parser.add_option("-l", "--log-level", dest="log_level",
-                help=_("specify the log level: "
-                "DEBUG, INFO, WARNING, ERROR, CRITICAL"))
-        parser.add_option("-u", "--user", dest="login",
-                help=_("specify the login user"))
-        parser.add_option("-s", "--server", dest="host",
-                help=_("specify the server hostname:port"))
+        parser = optparse.OptionParser(
+            version=("GNU Health %s" % __version__),
+            usage="Usage: %prog [options] [url]")
+        parser.add_option(
+            "-c", "--config", dest="config",
+            help=_("specify alternate config file"))
+        parser.add_option(
+            "-d", "--dev", action="store_true",
+            default=False, dest="dev",
+            help=_("development mode"))
+        parser.add_option(
+            "-v", "--verbose", action="store_true",
+            default=False, dest="verbose",
+            help=_("logging everything at INFO level"))
+        parser.add_option(
+            "-l", "--log-level", dest="log_level",
+            help=_("specify the log level: "
+                   "DEBUG, INFO, WARNING, ERROR, CRITICAL"))
+        parser.add_option(
+            "-u", "--user", dest="login", help=_("specify the login user"))
+        parser.add_option(
+            "-s", "--server", dest="host",
+            help=_("specify the server hostname:port"))
         opt, self.arguments = parser.parse_args()
         self.rcfile = opt.config or os.path.join(
             get_config_dir(), 'gnuhealth-client.conf')
@@ -196,4 +199,3 @@ GH_ABOUT = GdkPixbuf.Pixbuf.new_from_file(
     os.path.join(PIXMAPS_DIR, 'gnuhealth-hmis-about.png'))
 
 BANNER = 'banner.png'
-
