@@ -6,7 +6,7 @@
 #########################################################################
 #
 # SPDX-FileCopyrightText: 2008-2021 The Tryton Community <info@tryton.org>
-# SPDX-FileCopyrightText: 2017-2022 GNU Health Community <info@gnuhealth.org>
+# SPDX-FileCopyrightText: 2017-2023 GNU Health Community <info@gnuhealth.org>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -184,7 +184,9 @@ class Main(Gtk.Application):
             return
 
         self.window = Gtk.ApplicationWindow(
-            application=self, title="GNU Health Hospital Management")
+            application=self)
+        title = self.get_main_title()
+        self.window.set_title(title)
         self.window.set_default_size(960, 720)
         self.window.maximize()
         self.window.set_position(Gtk.WindowPosition.CENTER)
@@ -336,6 +338,17 @@ class Main(Gtk.Application):
         msg = "Connected to GNU Health Server"
         self.activity_log_entry(msg, 'info')
 
+    def get_main_title(self):
+        user = CONFIG['login.login']
+        host = CONFIG['login.host']
+        db = CONFIG['login.db']
+        conn_info = f'{user}@{host}/{db}'
+        if CONFIG['client.title']:
+            res = f"{CONFIG['client.title']} - {conn_info}"
+        else:
+            res = conn_info
+        return res
+        
     def gnuhealth_cli(self):
         self.cli.grab_focus()
 
